/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: msgengine_l.h 950 2006-02-22 19:39:02Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef AH_MSGENGINE_L_H
#define AH_MSGENGINE_L_H

#include "msgengine.h"

void AH_MsgEngine_SetUser(GWEN_MSGENGINE *e, AB_USER *u);

#endif /* AH_MSGENGINE_H */

